@@ -3,17 +3,17 @@ use warnings;
 
 package DBIx::Migration;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
-use parent qw( Class::Accessor::Fast );
+use subs 'dbh';
+
+use Class::Tiny qw( debug dbh dir dsn password username );
 
 use DBI                   qw();
 use File::Slurp           qw();
 use File::Spec::Functions qw();
 use Try::Tiny             qw();
 
-__PACKAGE__->mk_accessors( qw( debug dir dsn password username ) );
-
 sub dbh {
   my $self = shift;
 
@@ -77,10 +77,11 @@ sub migrate {
         my $name = $file->{ name };
         my $ver  = $file->{ version };
         print qq/Processing "$name"\n/ if $self->debug;
-        my $text = File::Slurp::read_file( $name );
-        $text =~ s/\s*--.*$//g;
-        # https://docs.liquibase.com/change-types/enddelimiter-sql.html
-        for my $sql ( split /;/, $text ) {
+        my $text      = File::Slurp::read_file( $name );
+        my $delimiter = ( $text =~ m/\A-- *dbix_migration_delimiter: *([[:graph:]])/ ) ? $1 : ';';
+        print qq/Delimiter is $delimiter\n/ if $self->debug;
+        $text =~ s/\s*--.*$//mg;
+        for my $sql ( split /$delimiter/, $text ) {
           $sql =~ s/\A\s*//;
           next unless $sql =~ /\w/;
           print qq/$sql\n/ if $self->debug;
